Release 0.9.1 (Maintenance Release)
[usenet/yapfaq.git] / yapfaq.pl
index 1257e63..5bc7919 100644 (file)
--- a/yapfaq.pl
+++ b/yapfaq.pl
@@ -1,6 +1,6 @@
 #! /usr/bin/perl -W
 #
# yapfaq Version 0.8.1 by Thomas Hochstein
 # (Original author: Marc Brockschmidt)
 #
 # This script posts any project described in its config-file. Most people
@@ -12,7 +12,7 @@
 # It can be redistributed and/or modified under the same terms under 
 # which Perl itself is published.
 
-our $VERSION = "0.9-prelease";
+our $VERSION = "0.91";
 
 # Please do not change this setting!
 # You may override the default .rc file (.yapfaqrc) by using "-c .rc file"
@@ -36,7 +36,6 @@ use strict;
 use Net::NNTP;
 use Net::Domain qw(hostfqdn);
 use Date::Calc qw(Add_Delta_YM Add_Delta_Days Delta_Days Today);
-use Fcntl ':flock'; # import LOCK_* constants
 use Getopt::Std;
 $Getopt::Std::STANDARD_HELP_VERSION = 1;
 my ($TDY, $TDM, $TDD) = Today(); #TD: Today's date
@@ -301,7 +300,8 @@ sub postfaq {
     $$NG = $Options{'t'};
     $MID =~ s/@/-$Timestamp-test@/g;
     $$ExtraHeaders .= "\n" if $$ExtraHeaders;
-    $$ExtraHeaders .= "X-Supersedes: $$Supersedes\nX-yapfaq-Remark: This is only a test message.";
+    $$ExtraHeaders .= "X-Supersedes: $$Supersedes\n" if $$Supersedes;
+    $$ExtraHeaders .= "X-yapfaq-Remark: This is only a test message.";
     undef $$Supersedes;
   }
 
@@ -1,6 +1,6 @@
 #! /usr/bin/perl -W
 #
-# yapfaq Version 0.8.1 by Thomas Hochstein
+# yapfaq Version 0.91 by Thomas Hochstein
 # (Original author: Marc Brockschmidt)
 #
This page took 0.010856 seconds and 4 git commands to generate.